/**
 * Copyright (C) 2017, hapjs.org. All rights reserved.
 */
import path from 'path'
import { exec } from 'child_process'

class ADBDriver {
  /**
   * 执行adb命令
   *
   * @param command  adb命令
   * @param option
   * @returns {Promise} 成功时返回stdout输出， 执行失败返回Error对象
   */
  static execCommand (command, option) {
    let cmd = command.split(' ')
    const binFile = ADBDriver.ADB_BINARY_FILE[process.platform]
    cmd[0] = binFile
    cmd = cmd.join(' ')

    return new Promise((resolve, reject) => {
      exec(cmd, option || {
        'stdio': 'inherit'
      }, (err, stdout, stderr) => {
        if (err) {
          console.error(`adb command： ${command} 执行出错： ${err.message}`)
          reject(err)
        }
        resolve(stdout)
      })
    }).catch(err => {
      console.error(`执行adb命令: ${command} 出错`)
      return err
    })
  }
}

ADBDriver.ADB_BINARY_FILE = {
  'win32': path.resolve(__dirname, 'bin/window/adb.exe'),
  'darwin': path.resolve(__dirname, 'bin/mac/adb'),
  'linux': path.resolve(__dirname, 'bin/linux/adb')
}

export default ADBDriver
